@@ -672,3 +672,77 @@ kill.factors <- function(dat, k=10){
   dat[filter] <- lapply(dat[filter], as.character)
   return(dat)
 }
+
+
+#' Good to go
+#'
+#' @description Loads all libraries used in scripts inside the selected path
+#' @param path Path where the scripts are located
+#' @param info List the libraries found?
+#' @param load Should the libraries found be loaded?
+#' @export
+good2go <- function(path=getwd(), info=TRUE, load=TRUE){
+  files <- list.files(path=path, pattern="\\.R$")
+  libraries <- unique(do.call("c", lapply(files, function(x) {
+    x <- readLines(x)
+    x[grepl("library\\(", x)]
+  }
+  )))
+  p_list <- gsub("\\)", "", gsub("library\\(", "", libraries))
+  if(load) lapply(p_list, function(x) require(x, character.only = TRUE, quietly=TRUE))
+  if(info) print(paste("Packages:", paste(gsub("\\)", "", gsub("library\\(", "", libraries)), collapse=", ")), quote=FALSE)
+}
+
+
+
+#' Forge
+#'
+#' @description Reshapes a data frame from wide to long format
+#' @param data data.frame
+#' @param affixes Affixes for repeated measures
+#' @param force.fixed Variables with matching affix to be excluded
+#' @param var.name Name for the new created variable (repetitions)
+#' @export
+#' @examples
+#' #Data frame in wide format
+#' df1 <- data.frame(id = 1:4, age = c(20, 30, 30, 35), score1 = c(2,2,3,4),
+#'                   score2 = c(2,1,3,1), score3 = c(1,1,0,1))
+#' df1
+#' #Data frame in long format
+#' forge(df1, affixes= c("1", "2", "3"))
+#'
+#' #Data frame in wide format with two repeated measured variables
+#' df2 <- data.frame(df1, var1 = c(15, 20, 16, 19), var3 = c(12, 15, 15, 17))
+#' df2
+#' #Missing times are filled with NAs
+#' forge(df2, affixes = c("1", "2", "3"))
+#'
+#' #Use of parameter force.fixed
+#' df3 <- df2[, -7]
+#' df3
+#' forge(df3, affixes=c("1", "2", "3"))
+#' forge(df3, affixes=c("1", "2", "3"), force.fixed = c("var1"))
+forge <- function(data, affixes, force.fixed=NULL, var.name="time"){
+  data_ord <- data[,order(names(data))]
+  indices <- data.frame(sapply(affixes, function(x) grepl(x, names(data_ord))))
+  if(!is.null(force.fixed)){
+    positions <- which(names(data_ord) %in% force.fixed)
+    indices[positions,] <- FALSE
+  }
+  cat("Repetitions for each variable: \n \n")
+  print(sort(table(unlist(lapply(indices, function(x) gsub(paste(affixes, collapse="|"), "", names(data_ord)[x])))), decreasing=TRUE))
+  listas <- lapply(indices, function(x) {
+    setNames(data_ord[,x, drop=FALSE], gsub(paste(affixes, collapse="|"), "", names(data_ord)[x]))
+  })
+  variables <- unique(unlist(lapply(listas, names)))
+  listas <- lapply(listas, function(x){
+    df <- data.frame(x, matrix(NA, nrow=nrow(data), ncol=length(variables[!variables %in% names(x)])))
+    names(df) <- c(names(x), variables[!variables %in% names(x)])
+    df
+  })
+  long <- do.call("rbind", listas)
+  fixed <- data_ord[,!apply(indices, 1, any)]
+  out <- data.frame(fixed[,na.omit(match(names(data), names(fixed)))][rep(1:nrow(data), length(affixes)),], long, affix=rep(affixes, each=nrow(data)))
+  names(out)[ncol(out)] <- var.name
+  out
+}
